using System;
using System.Collections.Generic;
using System.Text;
using System.Security.Principal;

namespace InfiniTec.DirectoryServices
{
    /// <summary>
    /// This class extends the <see cref="ActiveDirectoryPrincipal"/> class with 
    /// properties available on ActiveDirectory groups.
    /// </summary>
    public class ActiveDirectoryGroup: ActiveDirectoryPrincipal
    {
        private const uint SecurityGroupFlag = 0x80000000;
        private const uint GroupMask = 0xff;

        /// <summary>
        /// Initializes a new instance of the <see cref="ActiveDirectoryGroup"/> class.
        /// </summary>
        /// <param name="distinguishedName">The distinguished Name.</param>
        /// <param name="connection">The connection.</param>
        public ActiveDirectoryGroup(string distinguishedName, Connection connection):
            base(distinguishedName, connection)         
        {
            AddRequiredFields(SchemaMapping.GroupSchema);
        }


        /// <summary>
        /// Initializes a new instance of the <see cref="ActiveDirectoryGroup"/> class.
        /// </summary>
        /// <param name="objectId">The object id.</param>
        /// <param name="connection">The connection.</param>
        public ActiveDirectoryGroup(Guid objectId, Connection connection):
            base(objectId, connection)
        {
            AddRequiredFields(SchemaMapping.GroupSchema);
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ActiveDirectoryGroup"/> class.
        /// </summary>
        /// <param name="identifier">The identifier.</param>
        /// <param name="connection">The connection.</param>
        public ActiveDirectoryGroup(SecurityIdentifier identifier, Connection connection):
            base(identifier, connection) {}

        /// <summary>
        /// Initializes a new instance of the <see cref="ActiveDirectoryGroup"/> class.
        /// </summary>
        /// <param name="baseItem">The base item.</param>
        public ActiveDirectoryGroup(Item baseItem): base(baseItem)
        {
        }

        /// <summary>
        /// Gets the members of the group.
        /// </summary>
        /// <value>The members of the group.</value>
        public IList<string> Members
        {
            get
            {
                return GetMultivaluedPropertyValue<string>(Constants.Group.Members);
            }
        }

        /// <summary>
        /// Gets the group scope.
        /// </summary>
        /// <value>The group scope.</value>
        public GroupScope? Scope
        {
            get
            {
                int? result;

                result = GetNullablePropertyValue<int>(Constants.Group.GroupType);
                return (result != null) ? (GroupScope?)(result & GroupMask) : null;
            }
        }

        /// <summary>
        /// Gets the type of the group.
        /// </summary>
        /// <value>The type of the group.</value>
        public GroupType? Type
        {
            get
            {
                int? result;
               
                result = GetNullablePropertyValue<int>(Constants.Group.GroupType);
                return (result != null) ? (GroupType?)(result & SecurityGroupFlag) : null;
            }
        }

   
    }
}
