using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Win32.SafeHandles;
using System.Net;
using System.Runtime.InteropServices;

namespace InfiniTec.DirectoryServices
{
    class AuthenticationSafeHandle: SafeHandleZeroOrMinusOneIsInvalid
    {
        public AuthenticationSafeHandle(): base(true)
        {

        }

        protected override bool ReleaseHandle()
        {
            NativeMethods.DsFreePasswordCredentials(handle);

            return true;
        }

        public static AuthenticationSafeHandle Create(NetworkCredential credential)
        {
            AuthenticationSafeHandle handle;
            uint result;

            result = NativeMethods.DsMakePasswordCredentials(credential.UserName, credential.Domain,
                credential.Password, out handle);
            if (result != NativeMethods.Success)
            {
                switch (result)
                {
                    case NativeMethods.InvalidParameter: throw new InvalidOperationException(string.Format("The specified user was invalid ({0})", GetUsername(credential)));
                    case NativeMethods.OutOfMemory: throw new OutOfMemoryException("Not enough memory");
                    default: throw new InvalidOperationException(string.Format("An unknown error while creating authentication handle (Error #{0})", result));
                }
            }
            return handle;
        }

        private static string GetUsername(NetworkCredential credential)
        {
            return (string.IsNullOrEmpty(credential.Domain) ? credential.UserName : credential.Domain + "\\" + credential.UserName);
        }
    }
}
