using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Win32.SafeHandles;
using System.Net;
using System.Threading;

namespace InfiniTec.DirectoryServices
{
    class DirectoryServiceConnectionSafeHandle : SafeHandleZeroOrMinusOneIsInvalid
    {
        AuthenticationSafeHandle _AuthenticationHandle;

        public DirectoryServiceConnectionSafeHandle()
            : base(true)
        {
        }

        protected override bool ReleaseHandle()
        {
            AuthenticationSafeHandle authHandle;

            NativeMethods.DsUnBind(handle);
            handle = IntPtr.Zero;

            authHandle = Interlocked.Exchange<AuthenticationSafeHandle>(ref _AuthenticationHandle, null);
            if (authHandle != null) authHandle.Dispose();

            return true;
        }

        public static DirectoryServiceConnectionSafeHandle Create(
            string domainControllerName, string dnsDomainName,
            NetworkCredential credential)
        {
            DirectoryServiceConnectionSafeHandle handle;
            uint result;
            AuthenticationSafeHandle authenticationHandle;

            authenticationHandle = AuthenticationSafeHandle.Create(credential);

            result = NativeMethods.DsBindWithCred(domainControllerName, dnsDomainName,
                authenticationHandle, out handle);

            handle._AuthenticationHandle = authenticationHandle;

            if (result == NativeMethods.Success) return handle;

            authenticationHandle.Dispose();

            switch (result)
            {
                case NativeMethods.InvalidDomainName: throw new ArgumentException("The specified domainname (" + dnsDomainName + ") is invalid.");
                case NativeMethods.NoSuchDomain: throw new ArgumentException("No domain controller is available for the specified domain (" + dnsDomainName + ") or the domain does not exist.");
                default: throw new InvalidOperationException("An unknown error occured while connection to the domain (" + dnsDomainName + "). Error #" + result.ToString());
            }
        }
    }



}
