using System;
using System.Collections.Generic;
using System.Text;
using System.Xml.XPath;
using System.Xml;

namespace InfiniTec.DirectoryServices
{
    /// <summary>
    /// Represents a multi-valued property of an Exchange <see cref="Item"/>
    /// </summary>
    /// <typeparam name="T">The type of the property</typeparam>
    public class MultiValuedProperty<T>: Property
    {
        PropertyValueCollection<T> _Values;

        /// <summary>
        /// Returns a list containing the elements of the property.
        /// </summary>
        public IList<T> Values
        {
            get { return _Values; }
        }

        /// <summary>
        /// Creates a new instance of this class using the specified namespace and local
        /// name.
        /// </summary>
        /// <param name="name">The full qualified name of the property</param>
        /// <param name="values">The initial values of the property</param>
        public MultiValuedProperty(string name,
            params T[] values): this(name, true, values)
        {
           
        }

        /// <summary>
        /// Creates a new instance of this class using the specified namespace and local
        /// name.
        /// </summary>
        /// <param name="name">sThe full qualified name of the property</param>
        /// <param name="values">The initial values of the property</param>
        /// <param name="hasChanged">True, if the value is marked as changed. False, otherwise.</param>
        internal MultiValuedProperty(string name, bool hasChanged,
            params T[] values)
            : base(name)
        {
            _Values = new PropertyValueCollection<T>(this);

            if (values != null) _Values.AddRange(values);

            if (hasChanged) SetChanged();
        }


    }
}
