using System;
using System.Collections.Generic;
using System.Text;

namespace InfiniTec.DirectoryServices
{
    /// <summary>
    /// This class contains various constants used in the InfiniTec.DirectoryServices namespace.
    /// </summary>
    public static class Constants
    {
        /// <summary>
        /// This class defines well known distinguished names
        /// </summary>
        public static class WellknownDistinguishedNames
        {
            /// <summary>
            /// theoot of the forest
            /// </summary>
            public const string RootDse = "";
        }
        /// <summary>
        /// This class defines property names with special semantics.
        /// </summary>
        public static class Special
        {
            /// <summary>
            /// This property specifies the AmbiguousNameResolution.
            /// </summary>
            public const string AmbiguousNameResolution = "anr";
        }
        /// <summary>
        /// This class defines properties common to most ActiveDirectory principal objects
        /// </summary>
        public static class Common
        {
            /// <summary>
            /// The property for NT4 logon name
            /// </summary>
            public const string NT4AccountName = "sAMAccountName";
            /// <summary>
            /// The property distinguished name.
            /// </summary>
            public const string DistinguishedName = "distinguishedName";
            /// <summary>
            /// The name of the the canonical name.
            /// </summary>
            public const string CanonicalName = "canonicalName";
            /// <summary>
            /// The name of the theelative name
            /// </summary>
            public const string RelativeName = "cn";
            /// <summary>
            /// The name of the the display name
            /// </summary>
            public const string DisplayName = "displayName";
            /// <summary>
            /// The name of the the object class
            /// </summary>
            public const string ObjectClass = "objectClass";
            /// <summary>
            /// The name of the the object category
            /// </summary>
            public const string ObjectCategory = "objectCategory";
            /// <summary>
            /// The name of the the object guid
            /// </summary>
            public const string ObjectGuid = "objectGUID";
            /// <summary>
            /// The name of the the security identifier
            /// </summary>
            public const string ObjectSid = "objectSid";
            /// <summary>
            /// The name of the the SAM account type
            /// </summary>
            public const string SAMAccountType = "sAMAccountType";
        }

        /// <summary>
        /// This class defines names of properties available on theootDSE node.
        /// </summary>
        public static class RootDse
        {
            /// <summary>
            /// The name of the the default naming context
            /// </summary>
            public const string DefaultNamingContext = "defaultNamingContext";
            /// <summary>
            /// The name of the theoot naming context
            /// </summary>
            public const string RootNamingContext = "rootDomainNamingContext";
            /// <summary>
            /// The name of the the configuration context
            /// </summary>
            public const string ConfigurationContext = "configurationNamingContext";
            /// <summary>
            /// The name of the the schema naming context
            /// </summary>
            public const string SchemaNamingContext = "schemaNamingContext";
            /// <summary>
            /// The name of the the naming contexts
            /// </summary>
            public const string NamingContexts = "namingContexts";
        }

        /// <summary>
        /// This class contains names of properties available on principal objects which 
        /// specify group membership.
        /// </summary>
        public static class GroupMembership
        {
            /// <summary>
            /// The property for the memberOf property.
            /// </summary>
            public const string MemberOf = "memberOf";
            /// <summary>
            /// The name of the the tokenGroups property.
            /// </summary>
            public const string TokenGroups = "tokenGroups";
            /// <summary>
            /// The name of the the globalAndUniversalTokenGroups property
            /// </summary>
            public const string GlobalAndUniversalTokenGroups = "tokenGroupsGlobalAndUniversal";
            /// <summary>
            /// The name of the the noGCAcceptableTokenGroups property
            /// </summary>
            public const string NoGCAcceptableTokenGroups = "tokenGroupsNoGCAcceptable";
        }

        /// <summary>
        /// This class defines names of properties available on group objects
        /// </summary>
        public static class Group
        {
            /// <summary>
            /// The name of the the members property
            /// </summary>
            public const string Members = "members";
            /// <summary>
            /// The name of the the groupType property
            /// </summary>
            public const string GroupType = "groupType";
        }

        /// <summary>
        /// This class defines names of properties available on user objects
        /// </summary>
        public static class User
        {
            /// <summary>
            /// The name of the the co property
            /// </summary>
            public const string Country = "co";
            /// <summary>
            /// The name of the the company property
            /// </summary>
            public const string Company = "company";
            /// <summary>
            /// The name of the the department property
            /// </summary>
            public const string Department = "department";
            /// <summary>
            /// The name of the the description property
            /// </summary>
            public const string Description = "description";
            /// <summary>
            /// The name of the the facsimileTelephoneNumber property
            /// </summary>
            public const string FaxNumber = "facsimileTelephoneNumber";
            /// <summary>
            /// The name of the the giveName property
            /// </summary>
            public const string FirstName = "givenName";
            /// <summary>
            /// The name of the the homePhone property
            /// </summary>
            public const string HomePhone = "homePhone";
            /// <summary>
            /// The name of the the intials property
            /// </summary>
            public const string Initials = "initials";
            /// <summary>
            /// The name of the the ipPhone property
            /// </summary>
            public const string IPPhone = "ipPhone";
            /// <summary>
            /// The name of the the l property
            /// </summary>
            public const string City = "l";
            /// <summary>
            /// The name of the the mail property
            /// </summary>
            public const string MailAddress = "mail";
            /// <summary>
            /// The name of the the proxyAddresses property
            /// </summary>
            public const string ProxyAddresses = "proxyAddresses";
            /// <summary>
            /// The name of the the manager property
            /// </summary>
            public const string Manager = "manager";
            /// <summary>
            /// The name of the the mobile property
            /// </summary>
            public const string Mobile = "mobile";
            /// <summary>
            /// The name of the the otherFacsimileTelephoneNumber property
            /// </summary>
            public const string OtherFaxNumbers = "otherFacsimileTelephoneNumber";
            /// <summary>
            /// The name of the the otherHomePhone property
            /// </summary>
            public const string OtherHomePhones = "otherHomePhone";
            /// <summary>
            /// The name of the the otherIpPhone property
            /// </summary>
            public const string OtherIPPhones = "otherIpPhone";
            /// <summary>
            /// The name of the the otherMobile property
            /// </summary>
            public const string OtherMobile = "otherMobile";
            /// <summary>
            /// The name of the the otherPager property
            /// </summary>
            public const string OtherPager = "otherPager";
            /// <summary>
            /// The name of the the otherTelephone property
            /// </summary>
            public const string OtherTelephoneNumbers = "otherTelephone";
            /// <summary>
            /// The name of the the pager property
            /// </summary>
            public const string PagerNumber = "pager";
            /// <summary>
            /// The name of the the physicalDeliveryOfficeName property
            /// </summary>
            public const string Office = "physicalDeliveryOfficeName";
            /// <summary>
            /// The name of the the postalCode property
            /// </summary>
            public const string PostalCode = "postalCode";
            /// <summary>
            /// The name of the the postOfficeBox property
            /// </summary>
            public const string PostOfficeBox = "postOfficeBox";
            /// <summary>
            /// The name of the the sn property
            /// </summary>
            public const string LastName = "sn";
            /// <summary>
            /// The name of the the st property
            /// </summary>
            public const string State = "st";
            /// <summary>
            /// The name of the the streetAddress property
            /// </summary>
            public const string StreetAddress = "streetAddress";
            /// <summary>
            /// The name of the the telephoneNumber property
            /// </summary>
            public const string TelephoneNumber = "telephoneNumber";
            /// <summary>
            /// The name of the the title property
            /// </summary>
            public const string Title = "title";
            /// <summary>
            /// The name of the the url property
            /// </summary>
            public const string OtherWebPage = "url";
            /// <summary>
            /// The name of the the userPrincipalName property
            /// </summary>
            public const string UserPrincipalName = "userPrincipalName";
            /// <summary>
            /// The name of the the wWWHomePage property
            /// </summary>
            public const string WebPage = "wWWHomePage";
        }

        /// <summary>
        /// This class defines names of object categories used in ActiveDirectory
        /// </summary>
        public static class ObjectCategories
        {
            /// <summary>
            /// A group object
            /// </summary>
            public const string Group = "Group";
            /// <summary>
            /// A user object
            /// </summary>
            public const string Person = "Person";
        }
        /// <summary>
        /// This class defines various object classes used in ActiveDirectory
        /// </summary>
        public static class ObjectClasses
        {
            /// <summary>
            /// A group object
            /// </summary>
            public const string Group = "group";
            /// <summary>
            /// A user object
            /// </summary>
            public const string User = "user";
            /// <summary>
            /// A contact object
            /// </summary>
            public const string Contact = "contact";
        }
    }
}
