using System;
using System.Collections.Generic;
using System.Text;
using System.Xml.XPath;

namespace InfiniTec.DirectoryServices
{
    /// <summary>
    /// Represents a single-valued property of an Exchange <see cref="Item"/>
    /// </summary>
    /// <typeparam name="T">The type of the property</typeparam>
    public class Property<T>: Property
    {
        private T _Value;

        /// <summary>
        /// Gets or sets the value of the item
        /// </summary>
        public T Value
        {
            get { return _Value; }
            set { _Value = value; SetChanged();  }
        }

     
        /// <summary>
        /// Creates a new instance of this class using the specified namespace and local
        /// name.
        /// </summary>
        /// <param name="name">The full qualified name of the property</param>
        /// <param name="value">The value of the property</param>
        public Property(string name, T value): this(name)
        {
            Value = value;
            SetChanged();
        }

        /// <summary>
        /// Creates a new instance of this class using the specified namespace and local
        /// name.
        /// </summary>
        /// <param name="name">The full qualified name of the property</param>
        public Property(string name): base(name)
        {

        }
    }
}
